@@ -3,8 +3,6 @@ use strict;
 use warnings;
 use Carp;
 use List::Util;
-use Data::Dumper qw(Dumper);
-use Data::PatternCompare;
 use Exporter qw(import);
 our @EXPORT_OK = qw(
     incr        reduces  flatten
@@ -18,18 +16,12 @@ our @EXPORT_OK = qw(
     is_empty    is_sub   flow        eql
 );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use constant ARG_PLACE_HOLDER => {};
 
 # -----------------------------------------------------------------------------#
 
-my $cmp = Data::PatternCompare->new;
-
-sub _is_subset {
-    return $cmp->pattern_match($_[0], $_[1]);
-}
-
 sub __ { ARG_PLACE_HOLDER };
 
 sub noop { return undef }
@@ -145,13 +137,6 @@ sub find {
     my $pred = shift;
     my $coll = shift // [];
 
-    if (!is_sub($pred)) {
-        return find(sub {
-            my $subset = shift;
-            return bool(_is_subset($subset, $pred))
-        }, $coll);
-    }
-
     return List::Util::first {
         $pred->($_)
     } @$coll;
@@ -161,13 +146,6 @@ sub filter {
     my $pred  = shift;
     my $coll = shift // [];
 
-    if (!is_sub($pred)) {
-        return filter(sub {
-            my $subset = shift;
-            return bool(_is_subset($subset, $pred))
-        }, $coll);
-    }
-
     return [grep { $pred->($_) } @$coll];
 }
 
@@ -175,13 +153,6 @@ sub some {
     my $pred = shift;
     my $coll = shift // [];
 
-    if (!is_sub($pred)) {
-        return some(sub {
-            my $subset = shift;
-            return bool(_is_subset($subset, $pred))
-        }, $coll);
-    }
-
     return bool(find($pred, $coll));
 }
 
@@ -189,13 +160,6 @@ sub every {
     my $pred = shift;
     my $coll = shift // [];
 
-    if (!is_sub($pred)) {
-        return every(sub {
-            my $subset = shift;
-            return bool(_is_subset($subset, $pred));
-        }, $coll);
-    }
-
     my $bool = List::Util::all {
         $pred->($_);
     } @$coll;
@@ -207,18 +171,7 @@ sub none {
     my $pred = shift;
     my $coll = shift // [];
 
-    if (!is_sub($pred)) {
-        return none(sub {
-            my $subset = shift;
-            return bool(_is_subset($subset, $pred));
-        }, $coll);
-    }
-
-    my $bool = List::Util::none {
-        $pred->($_)
-    } @$coll;
-
-    return bool($bool);
+    return some($pred, $coll) ? 0 : 1;
 }
 
 sub incr {
@@ -994,36 +947,6 @@ Iterates over elements of collection, returning the first element predicate retu
 
     # { name => 'sally', age => 25 }
 
-    # find also supports 'iteratee object shorthand'
-
-    my $people = [
-        {
-            name          => 'john',
-            age           => 25,
-            favorite_food => 'broccoli',
-        },
-        {
-            name          => 'Sally',
-            age           => 25,
-            favorite_food => 'oranges',
-        },
-        {
-            name          => 'Old Greg',
-            age           => 100,
-            favorite_food => 'you do not want to know,
-        }
-    ]
-
-    find({ favorite_food => 'broccoli' }, $people);
-
-    # [
-    #     {
-    #         name          => 'Sally',
-    #         age           => 25,
-    #         favorite_food => 'broccoli',
-    #     },
-    # ]
-
 =cut
 
 =head2 filter
@@ -1061,17 +984,6 @@ Iterates over elements of collection, returning only elements the predicate retu
     #    }
     # ]
 
-    # Filter also supports 'iteratee object shorthand'
-
-    filter({ name => 'John' }, $people);
-
-    # [
-    #    {
-    #        name => 'john',
-    #        age  => 25,
-    #    },
-    # ]
-
 =cut
 
 =head2 none
@@ -1108,12 +1020,6 @@ If one element is found to return truthy for the given predicate, none returns 0
 
     # 1
 
-    # none also supports 'iteratee object shorthand'
-
-    none({ name => 'Black Bart' }, $people);
-
-    # 1
-
 =cut
 
 =head2 every
@@ -1135,30 +1041,6 @@ return truthy. If all elements cause predicate to return truthy, every returns 1
 
     # 0
 
-    # every also supports 'iteratee object shorthand'
-
-    my $people = [
-        {
-            name => 'john',
-            age => 25,
-            favorite_food => 'broccoli',
-        },
-        {
-            name => 'Sally',
-            age => 25,
-            favorite_food => 'broccoli',
-        },
-        {
-            name => 'Old Greg',
-            age => 100,
-            favorite_food => 'you do not want to know,
-        }
-    ]
-
-    every({ favorite_food => 'broccoli' }, $people)
-
-    # 0
-
 =cut
 
 =head2 some
@@ -1180,30 +1062,6 @@ Iteration is stopped once predicate returns truthy.
 
     # 1
 
-    # some also supports 'iteratee object shorthand'
-
-    my $people = [
-        {
-            name => 'john',
-            age => 25,
-            favorite_food => 'broccoli',
-        },
-        {
-            name => 'Sally',
-            age => 25,
-            favorite_food => 'broccoli',
-        },
-        {
-            name => 'Old Greg',
-            age => 100,
-            favorite_food => 'you do not want to know,
-        }
-    ]
-
-    some({ favorite_food => 'broccoli' }, $people)
-
-    # 1
-
 =cut
 
 =head2 partial
